@@ -620,7 +620,7 @@ class MyApp(wx.App):
 
 
     def OnHelpAboutMaemo(self,event):
-        Text = """pyobd-0.9.2-13
+        Text = """pyobd-0.9.2-14beta
 Adapted to n900 by m750
 Now work only with BT ELM OBD devices. 
 
